@@ -18,7 +18,7 @@ class AbstractCallback(metaclass=abc.ABCMeta):
 
     @property
     def empty(self) -> bool:
-        return not len(self.length)
+        return not self.length
 
     @property
     def length(self) -> int:
